# Clean workspace 
rm(list=ls())

# Required libraries 
library(SNPRelate)
library(plyr)
library(tidyverse)
library(CMplot)

sessionInfo()

###### PCA #####

genetics.vcf <- "./filtered_SNPs.recode.vcf"

snpgdsVCF2GDS(genetics.vcf, "SNPs.gds")


(genetics.gds <- snpgdsOpen("./SNPs.gds"))

snpgdsSummary(genetics.gds)

index.gdsn(genetics.gds, "sample.id")


# PCA
PCA <- snpgdsPCA(genetics.gds, autosome.only = F)

PCA.percent <- PCA$varprop*100


sample.id <- read.gdsn(index.gdsn(genetics.gds, "sample.id"))
sample.id

#list of ecotype populations, list is in order of vcf file
pop <- scan("./populations.txt", what=character())
pop
tab <- data.frame(sample.id = PCA$sample.id,
                  pop = factor(pop)[match(PCA$sample.id, sample.id)],
                  EV1 = PCA$eigenvect[,1],    # the first eigenvector
                  EV2 = PCA$eigenvect[,2],   # the second eigenvector
                  EV3 = PCA$eigenvect[,3],
                  EV4 = PCA$eigenvect[,4],
                  EV5 = PCA$eigenvect[,5],
                  EV6 = PCA$eigenvect[,6],
                  EV7 = PCA$eigenvect[,7],
                  EV8 = PCA$eigenvect[,8],# the second eigenvector
                  stringsAsFactors = FALSE)



cbPalette <- c("#000000", "#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7")
cbPalette <- cbPalette[as.integer(tab$pop)]

plot(tab$EV1, tab$EV2, col=as.integer(tab$pop), xlab="eigenvector 1 (9.98%)", ylab="eigenvector 2 (9.35%)", pch=16)
legend("topright", legend=c("Awe Bn", "Awe Pl", "Dug Bn", "Dug Pl", "Sea Bn", "Sea Pl", "Tay Bn", "Tay Pl"), 
       col= 1:nlevels(tab$pop), pch=16)

# LD pruning
LD <- snpgdsLDpruning(genetics.gds, ld.threshold=0.2, autosome.only = F)

snpset.id <- unlist(LD)

LD.PCA <- snpgdsPCA(genetics.gds, snp.id=snpset.id, num.thread=2, autosome.only = F)

LD.PCA.percent <- LD.PCA$varprop*100

sample.id <- read.gdsn(index.gdsn(genetics.gds, "sample.id"))

LD.tab <- data.frame(sample.id = LD.PCA$sample.id,
                  pop = factor(pop)[match(LD.PCA$sample.id, sample.id)],
                  EV1 = LD.PCA$eigenvect[,1],    # the first eigenvector
                  EV2 = LD.PCA$eigenvect[,2],    # the second eigenvector
                  stringsAsFactors = FALSE)


plot(LD.tab$EV2, LD.tab$EV1, col=as.integer(LD.tab$pop), xlab="eigenvector 2", ylab="eigenvector 1", pch=16)
legend("top", legend=c("Awe Bn", "Awe Pl", "Dug Bn", "Dug Pl", "Sea Bn", "Sea Pl", "Tay Bn", "Tay Pl"),
       pch=16 , col=1:nlevels(LD.tab$pop))

snpgdsClose(genetics.gds)


### Gemma model - use output from gemma model

gemma.head <- read.table("./head_PC1_5.assoc.txt", header= T)

gemma.headsig <- gemma.head %>%
  filter(p_wald < (0.05/length(snpset.id)))

gemma.body <- read.table("./body_PC1_5.assoc.txt", header= T)

gemma.bodysig <- gemma.body %>%
  filter(p_wald < (0.05/length(snpset.id)))


# Manhattan Plot - remove SNPs mapped to unmapped scaffolds
gemma.headedit <- gemma.head
gemma.headedit <- gemma.headedit[1:9810, ]

gemma.headedit$chr[gemma.headedit$chr == "NC_036838.1"] <- 1
gemma.headedit$chr[gemma.headedit$chr == "NC_036839.1"] <- 2
gemma.headedit$chr[gemma.headedit$chr == "NC_036840.1"] <- 3
gemma.headedit$chr[gemma.headedit$chr == "NC_036841.1"] <- 4
gemma.headedit$chr[gemma.headedit$chr == "NC_036842.1"] <- 5
gemma.headedit$chr[gemma.headedit$chr == "NC_036843.1"] <- 6
gemma.headedit$chr[gemma.headedit$chr == "NC_036844.1"] <- 7
gemma.headedit$chr[gemma.headedit$chr == "NC_036845.1"] <- 8
gemma.headedit$chr[gemma.headedit$chr == "NC_036846.1"] <- 9
gemma.headedit$chr[gemma.headedit$chr == "NC_036847.1"] <- 10
gemma.headedit$chr[gemma.headedit$chr == "NC_036848.1"] <- 11
gemma.headedit$chr[gemma.headedit$chr == "NC_036849.1"] <- 12
gemma.headedit$chr[gemma.headedit$chr == "NC_036850.1"] <- 13
gemma.headedit$chr[gemma.headedit$chr == "NC_036851.1"] <- 14
gemma.headedit$chr[gemma.headedit$chr == "NC_036852.1"] <- 15
gemma.headedit$chr[gemma.headedit$chr == "NC_036853.1"] <- 16
gemma.headedit$chr[gemma.headedit$chr == "NC_036854.1"] <- 17
gemma.headedit$chr[gemma.headedit$chr == "NC_036855.1"] <- 18
gemma.headedit$chr[gemma.headedit$chr == "NC_036856.1"] <- 19
gemma.headedit$chr[gemma.headedit$chr == "NC_036857.1"] <- 20
gemma.headedit$chr[gemma.headedit$chr == "NC_036858.1"] <- 21
gemma.headedit$chr[gemma.headedit$chr == "NC_036859.1"] <- 22
gemma.headedit$chr[gemma.headedit$chr == "NC_036860.1"] <- 23
gemma.headedit$chr[gemma.headedit$chr == "NC_036861.1"] <- 24
gemma.headedit$chr[gemma.headedit$chr == "NC_036862.1"] <- 25
gemma.headedit$chr[gemma.headedit$chr == "NC_036863.1"] <- 26
gemma.headedit$chr[gemma.headedit$chr == "NC_036864.1"] <- 27
gemma.headedit$chr[gemma.headedit$chr == "NC_036865.1"] <- 28
gemma.headedit$chr[gemma.headedit$chr == "NC_036866.1"] <- 29
gemma.headedit$chr[gemma.headedit$chr == "NC_036867.1"] <- 30
gemma.headedit$chr[gemma.headedit$chr == "NC_036868.1"] <- 31
gemma.headedit$chr[gemma.headedit$chr == "NC_036869.1"] <- 32
gemma.headedit$chr[gemma.headedit$chr == "NC_036870.1"] <- 33
gemma.headedit$chr[gemma.headedit$chr == "NC_036871.1"] <- 34
gemma.headedit$chr[gemma.headedit$chr == "NC_036872.1"] <- 35
gemma.headedit$chr[gemma.headedit$chr == "NC_036873.1"] <- 36
gemma.headedit$chr[gemma.headedit$chr == "NC_036874.1"] <- 37
gemma.headedit$chr[gemma.headedit$chr == "NC_036875.1"] <- 38
gemma.headedit$chr[gemma.headedit$chr == "NC_036876.1"] <- 39

gemma.headedit$chr <- as.numeric(gemma.headedit$chr)

gemma.headedit <- gemma.headedit[, c(1:3, 28)]

gemma.headedit <- gemma.headedit[, c(2,1,3,4)]

CMplot(gemma.headedit,type="p",plot.type="m",LOG10=TRUE,threshold=NULL,file="jpg",memo="",dpi=300,
       file.output=TRUE,verbose=TRUE,width=14,height=6,chr.labels.angle=45)

# List of highly associated SNPs shared for head and body shape
SNPs <- c("21217:38:+", "29601:43:-", "41853:32:-", "54154:45:+", "80591:14:-", "99485:31:+", "107573:35:+", "145282:60:-",
          "174084:15:+", "216781:23:-", "240797:14:+", "244999:59:+", "246171:43:-", "255879:59:-", "255890:25:-",
          "255894:33:+", "255894:39:+", "255894:47:+", "255894:52:+", "255894:60:+", "255894:66:+",  "270628:37:+",
          "270974:19:+", "274704:45:+", "297543:31:-", "298572:53:-", "354711:51:+", "354718:27:-", "375029:30:-",
          "417302:26:-", "483821:12:+", "520322:25:-", "536237:62:-", "600524:24:+", "624187:36:+", "647856:40:+",
          "649827:29:+", "650421:30:+", "674628:42:+", "691491:25:-", "691491:24:-", "694298:63:-", "723386:63:-",
          "725035:61:-", "792982:23:+", "793403:37:-", "802878:45:-", "807550:36:+", "807575:10:-", "816436:34:-")

CMplot(gemma.headedit,  plot.type="m", col=c("grey30","grey60"), LOG10=TRUE, threshold=0.05/7329, amplify=TRUE, cex = 3,
       chr.den.col=NULL, signal.col= "#56B4E9", signal.cex=3, signal.pch= 19, highlight = SNPs, highlight.cex=3, 
       highlight.col = "#E69F00",highlight.pch= 19, file="jpg",memo="",dpi=600,file.output=T,verbose=TRUE,width=30,
       height=10, chr.labels.angle=45, cex.lab= 3, cex.axis = 2.3, mar=c(5,7,1,1), threshold.lwd = 5, ylab.pos = 3.5,
       chr.border= T, band= 2)


gemma.bodyedit <- gemma.body
gemma.bodyedit <- gemma.bodyedit[1:9741,]

gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036838.1"] <- 1
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036839.1"] <- 2
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036840.1"] <- 3
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036841.1"] <- 4
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036842.1"] <- 5
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036843.1"] <- 6
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036844.1"] <- 7
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036845.1"] <- 8
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036846.1"] <- 9
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036847.1"] <- 10
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036848.1"] <- 11
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036849.1"] <- 12
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036850.1"] <- 13
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036851.1"] <- 14
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036852.1"] <- 15
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036853.1"] <- 16
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036854.1"] <- 17
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036855.1"] <- 18
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036856.1"] <- 19
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036857.1"] <- 20
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036858.1"] <- 21
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036859.1"] <- 22
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036860.1"] <- 23
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036861.1"] <- 24
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036862.1"] <- 25
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036863.1"] <- 26
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036864.1"] <- 27
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036865.1"] <- 28
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036866.1"] <- 29
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036867.1"] <- 30
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036868.1"] <- 31
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036869.1"] <- 32
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036870.1"] <- 33
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036871.1"] <- 34
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036872.1"] <- 35
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036873.1"] <- 36
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036874.1"] <- 37
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036875.1"] <- 38
gemma.bodyedit$chr[gemma.bodyedit$chr == "NC_036876.1"] <- 39

gemma.bodyedit$chr <- as.numeric(gemma.bodyedit$chr)

gemma.bodyedit <- gemma.bodyedit[, c(1:3, 28)]

gemma.bodyedit <- gemma.bodyedit[, c(2,1,3,4)]

CMplot(gemma.bodyedit,type="p",plot.type="m",LOG10=TRUE,threshold=NULL,file="jpg",memo="",dpi=300,
       file.output=TRUE,verbose=TRUE,width=14,height=6,chr.labels.angle=45)

SNPs <- c("21217:38:+", "29601:43:-", "41853:32:-", "54154:45:+", "80591:14:-", "99485:31:+", "107573:35:+", "145282:60:-",
          "174084:15:+", "216781:23:-", "240797:14:+", "244999:59:+", "246171:43:-", "255879:59:-", "255890:25:-",
          "255894:33:+", "255894:39:+", "255894:47:+", "255894:52:+", "255894:60:+", "255894:66:+",  "270628:37:+",
          "270974:19:+", "274704:45:+", "297543:31:-", "298572:53:-", "354711:51:+", "354718:27:-", "375029:30:-",
          "417302:26:-", "483821:12:+", "520322:25:-", "536237:62:-", "600524:24:+", "624187:36:+", "647856:40:+",
          "649827:29:+", "650421:30:+", "674628:42:+", "691491:25:-", "691491:24:-", "694298:63:-", "723386:63:-",
          "725035:61:-", "792982:23:+", "793403:37:-", "802878:45:-", "807550:36:+", "807575:10:-", "816436:34:-")

CMplot(gemma.bodyedit,  plot.type="m", col=c("grey30","grey60"), LOG10=TRUE, threshold=0.05/7329,cex=3, amplify=TRUE,
       chr.den.col=NULL, signal.col= "#56B4E9", signal.cex=3, signal.pch= 19, highlight = SNPs, highlight.cex=3, 
       highlight.col = "#E69F00",highlight.pch= 19, file="jpg",memo="",dpi=600,file.output=TRUE,verbose=TRUE,width=30,
       height=10, chr.labels.angle=45, cex.lab= 3, cex.axis = 2.3, mar=c(5,7,1,1), threshold.lwd = 5, ylab.pos = 3.5,
       chr.border= T, band= 2)
