# Recombination rates

rm(list=ls())

library(tidyverse)
library(ggplot2)
library(MareyMap)
library(windowscanr)
sessionInfo()

RR <- read.csv("./AC_linkagemap_genome_mapped_edited.csv")

# plot recombination rate across each chromosome to help determine appropriate cubic spline to use
RR$physplot <- RR$phys/1000000

bp <- ggplot(RR, aes(x= physplot, y= gen_transpose))+
  geom_point() +
  scale_y_continuous(breaks= seq(0,120,40))+
  xlab("physical distance [Mb]")+
  ylab("genetic distance [cM]")
bp + facet_wrap( ~ map, ncol= 8, scale= "free_x") 

startMareyMapGUI()
#assign spline values to each chromosome using AC_LM file and export

# Recombination rate across windows using the export from Mareymap

recombrate <- read.table("./Marey_map_cubic_spline_edited.txt", header= T)


recombrate[, 7][recombrate[, 7] <0] <- 0

ggplot(recombrate, aes(phys, spline)) + geom_point() + 
  facet_wrap(~ map, scales = "free_x", ncol= 8)


res <- winScan(x = recombrate,
               groups = "map",
               position = "phys",
               values = c("spline"),
               win_size = 1000000,
               win_step = 1000000,
               funs = c("mean"))

sum(is.na(res$spline_mean))

write.csv(res, "Recombination_windows_1MB.csv")
